/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type ErrorResponse = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type Money = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResult = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequest = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResult = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ClosedObject = {} & {
  [key: string]: any;
};
export declare type OpenObject = {} & {
  [key: string]: any;
};
export declare type NoPropertiesAllowed = {};
export declare type SpecifiedPropertiesAllowed = {} & {
  [key: string]: any;
};
export declare type MoneyMnemonic = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type BoolFilter = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultBase = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type MatchAllQuery = {} & {
  [key: string]: any;
};
export declare type FilteredQuery = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilter = {
  query: any;
} & {
  [key: string]: any;
};
export declare type Query = {
  boolQuery?: BoolQuery;
  filteredQuery?: FilteredQuery;
  matchAllQuery?: MatchAllQuery;
  nestedQuery?: NestedQuery;
  termQuery?: TermQuery;
  textQuery?: TextQuery;
} & {
  [key: string]: any;
};
export declare type TermQuery = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilter = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQuery = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2Filter = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQuery = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultBase = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type NestedQuery = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type Filter = {
  boolFilter?: BoolFilter;
  queryFilter?: QueryFilter;
  range2Filter?: Range2Filter;
  rangeFilter?: RangeFilter;
  termFilter?: TermFilter;
} & {
  [key: string]: any;
};
export declare type Sort = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilter = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type SearchRequestBase = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type TaxItems = {
  taxItems?: Array<TaxItem>;
} & {
  [key: string]: any;
};
export declare type PaymentCardSpec = {
  cardType?: string;
  checksumVerificationEnabled?: boolean;
  description?: string;
  image?: string;
  name?: string;
  numberLengths?: Array<string>;
  numberPrefixes?: Array<string>;
} & {
  [key: string]: any;
};
export declare type OrderAddress = {
  address1?: string;
  address2?: string;
  city?: string;
  companyName?: string;
  countryCode?: string;
  firstName?: string;
  fullName?: string;
  id?: string;
  jobTitle?: string;
  lastName?: string;
  phone?: string;
  postBox?: string;
  postalCode?: string;
  salutation?: string;
  secondName?: string;
  stateCode?: string;
  suffix?: string;
  suite?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type BasketsResult = {
  baskets: Array<Basket>;
  total: number;
} & {
  [key: string]: any;
};
export declare type PaymentCard = {
  cardType?: string;
  creditCardExpired?: boolean;
  creditCardToken?: string;
  expirationMonth?: number;
  expirationYear?: number;
  holder?: string;
  issueNumber?: string;
  maskedNumber?: string;
  numberLastDigits?: string;
  validFromMonth?: number;
  validFromYear?: number;
};
export declare type NotesResult = {
  notes?: Array<Note>;
} & {
  [key: string]: any;
};
export declare type ShippingItem = {
  adjustedTax?: number;
  basePrice?: number;
  itemId?: string;
  itemText?: string;
  price?: number;
  priceAdjustments?: Array<PriceAdjustment>;
  priceAfterItemDiscount?: number;
  shipmentId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type Discount = {
  amount?: number;
  percentage?: number;
  priceBookId?: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type Note = {
  createdBy?: string;
  creationDate?: any;
  id?: string;
  subject?: string;
  text?: string;
};
export declare type CouponItem = {
  code: string;
  couponItemId?: string;
  statusCode?: string;
  valid?: boolean;
} & {
  [key: string]: any;
};
export declare type PromotionLink = {
  calloutMsg?: string;
  name?: string;
  promotionId?: string;
  title?: string;
};
export declare type ShippingPromotion = {
  calloutMsg?: string;
  promotionId?: string;
  promotionName?: string;
} & {
  [key: string]: any;
};
export declare type ProductItem = {
  adjustedTax?: number;
  basePrice?: number;
  bonusDiscountLineItemId?: string;
  bonusProductLineItem?: boolean;
  bundledProductItems?: Array<ProductItem>;
  gift?: boolean;
  giftMessage?: string;
  inventoryId?: string;
  itemId?: string;
  itemText?: string;
  optionItems?: Array<OptionItem>;
  price?: number;
  priceAdjustments?: Array<PriceAdjustment>;
  priceAfterItemDiscount?: number;
  priceAfterOrderDiscount?: number;
  productId?: string;
  productListItem?: ProductListItemReference;
  productName?: string;
  quantity?: number;
  shipmentId?: string;
  shippingItemId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type BasketPaymentInstrumentRequest = {
  amount?: number;
  bankRoutingNumber?: string;
  giftCertificateCode?: string;
  paymentCard?: OrderPaymentCardRequest;
  paymentMethodId?: string;
} & {
  [key: string]: any;
};
export declare type Taxes = {
  taxes: {} & {
    [key: string]: any;
  };
};
export declare type OrderPaymentInstrument = {
  amount?: number;
  authorizationStatus?: Status;
  bankRoutingNumber?: string;
  maskedGiftCertificateCode?: string;
  paymentCard?: PaymentCard;
  paymentInstrumentId?: string;
  paymentMethodId?: string;
} & {
  [key: string]: any;
};
export declare type BonusDiscountLineItem = {
  bonusProducts?: Array<ProductDetailsLink>;
  couponCode?: string;
  id?: string;
  maxBonusItems?: number;
  promotionId?: string;
} & {
  [key: string]: any;
};
export declare type PaymentMethodResult = {
  applicablePaymentMethods?: Array<PaymentMethod>;
} & {
  [key: string]: any;
};
export declare type Shipment = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  gift?: boolean;
  giftMessage?: string;
  merchandizeTotalTax?: number;
  productSubTotal?: number;
  productTotal?: number;
  shipmentId?: string;
  shipmentNo?: string;
  shipmentTotal?: number;
  shippingAddress?: OrderAddress;
  shippingMethod?: ShippingMethod;
  shippingStatus?: string;
  shippingTotal?: number;
  shippingTotalTax?: number;
  taxTotal?: number;
  trackingNumber?: string;
} & {
  [key: string]: any;
};
export declare type CustomerInfo = {
  customerId?: string;
  customerName?: string;
  customerNo?: string;
  email: string;
} & {
  [key: string]: any;
};
export declare type SimpleLink = {};
export declare type PriceAdjustment = {
  appliedDiscount?: Discount;
  couponCode?: string;
  createdBy?: string;
  creationDate?: any;
  custom?: boolean;
  itemText?: string;
  lastModified?: any;
  manual?: boolean;
  price?: number;
  priceAdjustmentId?: string;
  promotionId?: string;
  promotionLink?: string;
  reasonCode?: string;
} & {
  [key: string]: any;
};
export declare type ShippingMethodResult = {
  applicableShippingMethods?: Array<ShippingMethod>;
  defaultShippingMethodId?: string;
} & {
  [key: string]: any;
};
export declare type ProductDetailsLink = {
  productDescription?: string;
  productId: string;
  productName?: string;
  title?: string;
};
export declare type OptionItem = {
  adjustedTax?: number;
  basePrice?: number;
  bonusDiscountLineItemId?: string;
  bonusProductLineItem?: boolean;
  bundledProductItems?: Array<ProductItem>;
  gift?: boolean;
  giftMessage?: string;
  inventoryId?: string;
  itemId?: string;
  itemText?: string;
  optionId: string;
  optionItems?: Array<OptionItem>;
  optionValueId: string;
  price?: number;
  priceAdjustments?: Array<PriceAdjustment>;
  priceAfterItemDiscount?: number;
  priceAfterOrderDiscount?: number;
  productId?: string;
  productListItem?: ProductListItemReference;
  productName?: string;
  quantity?: number;
  shipmentId?: string;
  shippingItemId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type ShippingMethod = {
  description?: string;
  externalShippingMethod?: string;
  id: string;
  name?: string;
  price?: number;
  shippingPromotions?: Array<ShippingPromotion>;
} & {
  [key: string]: any;
};
export declare type Basket = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  agentBasket?: boolean;
  basketId?: string;
  billingAddress?: OrderAddress;
  bonusDiscountLineItems?: Array<BonusDiscountLineItem>;
  channelType?: string;
  couponItems?: Array<CouponItem>;
  creationDate?: any;
  currency?: string;
  customerInfo?: CustomerInfo;
  giftCertificateItems?: Array<GiftCertificateItem>;
  inventoryReservationExpiry?: any;
  lastModified?: any;
  merchandizeTotalTax?: number;
  notes?: SimpleLink;
  orderPriceAdjustments?: Array<PriceAdjustment>;
  orderTotal?: number;
  paymentInstruments?: Array<OrderPaymentInstrument>;
  productItems?: Array<ProductItem>;
  productSubTotal?: number;
  productTotal?: number;
  shipments?: Array<Shipment>;
  shippingItems?: Array<ShippingItem>;
  shippingTotal?: number;
  shippingTotalTax?: number;
  sourceCode?: string;
  taxTotal?: number;
  taxation?: string;
} & {
  [key: string]: any;
};
export declare type OrderPaymentInstrumentRequest = {
  amount?: number;
  bankRoutingNumber?: string;
  giftCertificateCode?: string;
  paymentCard?: OrderPaymentCardRequest;
  paymentMethodId?: string;
} & {
  [key: string]: any;
};
export declare type GiftCertificateItem = {
  amount: number;
  giftCertificateItemId?: string;
  message?: string;
  recipientEmail: string;
  recipientName?: string;
  senderName?: string;
  shipmentId?: string;
} & {
  [key: string]: any;
};
export declare type ProductListLink = {
  description?: string;
  name?: string;
  public?: boolean;
  title?: string;
  type?: string;
} & {
  [key: string]: any;
};
export declare type Order = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  billingAddress?: OrderAddress;
  bonusDiscountLineItems?: Array<BonusDiscountLineItem>;
  channelType?: string;
  confirmationStatus?: string;
  couponItems?: Array<CouponItem>;
  createdBy?: string;
  creationDate?: any;
  currency?: string;
  customerInfo?: CustomerInfo;
  customerName?: string;
  exportStatus?: string;
  externalOrderStatus?: string;
  giftCertificateItems?: Array<GiftCertificateItem>;
  globalPartyId?: string;
  lastModified?: any;
  merchandizeTotalTax?: number;
  notes?: SimpleLink;
  orderNo?: string;
  orderPriceAdjustments?: Array<PriceAdjustment>;
  orderToken?: string;
  orderTotal?: number;
  paymentInstruments?: Array<OrderPaymentInstrument>;
  paymentStatus?: string;
  productItems?: Array<ProductItem>;
  productSubTotal?: number;
  productTotal?: number;
  shipments?: Array<Shipment>;
  shippingItems?: Array<ShippingItem>;
  shippingStatus?: string;
  shippingTotal?: number;
  shippingTotalTax?: number;
  siteId?: string;
  sourceCode?: string;
  status?: string;
  taxTotal?: number;
  taxation?: string;
} & {
  [key: string]: any;
};
export declare type OrderPaymentCardRequest = {
  cardType?: string;
  creditCardToken?: string;
  expirationMonth?: number;
  expirationYear?: number;
  holder?: string;
  issueNumber?: string;
  maskedNumber?: string;
  validFromMonth?: number;
  validFromYear?: number;
};
export declare type PaymentMethod = {
  cards?: Array<PaymentCardSpec>;
  description?: string;
  id: string;
  image?: string;
  name?: string;
  paymentProcessorId?: string;
} & {
  [key: string]: any;
};
export declare type TaxItem = {
  id: string;
  rate: number;
  value?: number;
};
export declare type Status = {
  code?: string;
  message?: string;
  status?: number;
};
export declare type ProductListItemReference = {
  id: string;
  priority?: number;
  productDetailsLink?: ProductDetailsLink;
  productList?: ProductListLink;
  public?: boolean;
  purchasedQuantity?: number;
  quantity?: number;
  type?: string;
};
