/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type CustomerAddress = {
  address1?: string;
  address2?: string;
  addressId: string;
  city?: string;
  companyName?: string;
  countryCode: string;
  creationDate?: any;
  etag?: string;
  firstName?: string;
  fullName?: string;
  jobTitle?: string;
  lastModified?: any;
  lastName: string;
  phone?: string;
  postBox?: string;
  postalCode?: string;
  salutation?: string;
  secondName?: string;
  stateCode?: string;
  suffix?: string;
  suite?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type CustomerList = {
  id: string;
} & {
  [key: string]: any;
};
export declare type CustomerSearchHit = {
  data: Customer;
  relevance: number;
} & {
  [key: string]: any;
};
export declare type CustomerAddressResult = {
  limit?: number;
  data?: Array<CustomerAddress>;
  offset?: number;
  total?: number;
} & {
  [key: string]: any;
};
export declare type Customer = {
  birthday?: any;
  companyName?: string;
  creationDate?: any;
  credentials?: Credentials;
  customerId?: string;
  customerNo: string;
  email?: string;
  fax?: string;
  firstName?: string;
  gender?: number;
  jobTitle?: string;
  lastLoginTime?: any;
  lastModified?: any;
  lastName: string;
  lastVisitTime?: any;
  phoneBusiness?: string;
  phoneHome?: string;
  phoneMobile?: string;
  preferredLocale?: string;
  previousLoginTime?: any;
  previousVisitTime?: any;
  primaryAddress?: CustomerAddress;
  salutation?: string;
  secondName?: string;
  suffix?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type Credentials = {
  enabled?: boolean;
  locked?: boolean;
  login: string;
  passwordQuestion?: string;
} & {
  [key: string]: any;
};
export declare type CustomerSearchResult = {
  hits: Array<CustomerSearchHit>;
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type Money = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResult = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequest = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResult = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ClosedObject = {} & {
  [key: string]: any;
};
export declare type OpenObject = {} & {
  [key: string]: any;
};
export declare type BoolFilter = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultBase = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type MatchAllQuery = {} & {
  [key: string]: any;
};
export declare type FilteredQuery = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilter = {
  query: any;
} & {
  [key: string]: any;
};
export declare type Query = {
  boolQuery?: BoolQuery;
  filteredQuery?: FilteredQuery;
  matchAllQuery?: MatchAllQuery;
  nestedQuery?: NestedQuery;
  termQuery?: TermQuery;
  textQuery?: TextQuery;
} & {
  [key: string]: any;
};
export declare type TermQuery = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilter = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQuery = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2Filter = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQuery = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultBase = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type NestedQuery = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type Filter = {
  boolFilter?: BoolFilter;
  queryFilter?: QueryFilter;
  range2Filter?: Range2Filter;
  rangeFilter?: RangeFilter;
  termFilter?: TermFilter;
} & {
  [key: string]: any;
};
export declare type Sort = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilter = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type SearchRequestBase = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type NoPropertiesAllowed = {};
export declare type SpecifiedPropertiesAllowed = {} & {
  [key: string]: any;
};
export declare type MoneyMnemonic = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type ErrorResponse = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
