/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type RevokeTokenRequest = {
  token: string;
  tokenTypeHint?: string;
} & {
  [key: string]: any;
};
export declare type IntrospectResponse = {
  active: boolean;
  scope: string;
  clientId: string;
  sub: string;
  exp: number;
  iat: number;
  tokenType: string;
} & {
  [key: string]: any;
};
export declare type ErrorResponse = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type IntrospectTokenRequest = {
  token: string;
  tokenTypeHint?: string;
} & {
  [key: string]: any;
};
export declare type TokenResponse = {
  accessToken: string;
  refreshToken: string;
  expiresIn: number;
  accessTokenType: string;
  usid: string;
} & {
  [key: string]: any;
};
export declare type TokenRequest = {
  refreshToken?: string;
  code?: string;
  usid?: string;
  grantType: string;
} & {
  [key: string]: any;
};
export declare type SearchRequest = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResult = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResult = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilter = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQuery = {} & {
  [key: string]: any;
};
export declare type FilteredQuery = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilter = {
  query: any;
} & {
  [key: string]: any;
};
export declare type Query = {
  boolQuery?: BoolQuery;
  filteredQuery?: FilteredQuery;
  matchAllQuery?: MatchAllQuery;
  nestedQuery?: NestedQuery;
  termQuery?: TermQuery;
  textQuery?: TextQuery;
} & {
  [key: string]: any;
};
export declare type TermQuery = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilter = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQuery = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2Filter = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQuery = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQuery = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type Filter = {
  boolFilter?: BoolFilter;
  queryFilter?: QueryFilter;
  range2Filter?: Range2Filter;
  rangeFilter?: RangeFilter;
  termFilter?: TermFilter;
} & {
  [key: string]: any;
};
export declare type Sort = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilter = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
