/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type SourceCodeGroup = {
  active?: boolean;
  activeRedirect?: SourceCodeRedirectInfo;
  cookieDuration?: number;
  creationDate?: any;
  description?: string;
  enabled?: boolean;
  endTime?: any;
  id: string;
  inactiveRedirect?: SourceCodeRedirectInfo;
  lastModified?: any;
  specifications?: Array<SourceCodeSpecification>;
  startTime?: any;
} & {
  [key: string]: any;
};
export declare type SourceCodeGroupSearchResult = {
  hits: Array<SourceCodeGroup>;
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type SourceCodeRedirectInfo = {
  locationType: string;
} & {
  [key: string]: any;
};
export declare type SourceCodeSpecification = {
  expression: string;
} & {
  [key: string]: any;
};
export declare type ErrorResponse = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type Money = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResult = {
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type SearchRequest = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: any;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResult = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type ClosedObject = {} & {
  [key: string]: any;
};
export declare type OpenObject = {} & {
  [key: string]: any;
};
export declare type MoneyMnemonic = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type BoolFilter = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultBase = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type MatchAllQuery = {} & {
  [key: string]: any;
};
export declare type FilteredQuery = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilter = {
  query: any;
} & {
  [key: string]: any;
};
export declare type Query = {
  boolQuery?: BoolQuery;
  filteredQuery?: FilteredQuery;
  matchAllQuery?: MatchAllQuery;
  nestedQuery?: NestedQuery;
  termQuery?: TermQuery;
  textQuery?: TextQuery;
} & {
  [key: string]: any;
};
export declare type TermQuery = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilter = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQuery = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2Filter = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQuery = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultBase = {
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type NestedQuery = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type Filter = {
  boolFilter?: BoolFilter;
  queryFilter?: QueryFilter;
  range2Filter?: Range2Filter;
  rangeFilter?: RangeFilter;
  termFilter?: TermFilter;
} & {
  [key: string]: any;
};
export declare type Sort = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilter = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type SearchRequestBase = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: any;
} & {
  [key: string]: any;
};
export declare type NoPropertiesAllowed = {};
export declare type SpecifiedPropertiesAllowed = {} & {
  [key: string]: any;
};
