/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type Money = {
  currencyMnemonic: string;
  value: number;
} & {
  [key: string]: any;
};
export declare type CategoryProductAssignmentSearchResult = {
  hits: Array<CategoryProductAssignment>;
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ProductOption = {
  customName: {} & {
    [key: string]: any;
  };
  defaultProductOptionValue: string;
  description: {} & {
    [key: string]: any;
  };
  id: string;
  image?: MediaFile;
  name: string;
  selectedOptionValue: string;
  shared: boolean;
  sortingMode: string;
  values: Array<ProductOptionValue>;
} & {
  [key: string]: any;
};
export declare type Master = {
  masterId: string;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type CategorySearchResult = {
  hits: Array<Category>;
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type Category = {
  catalogId?: string;
  categories?: Array<Category>;
  creationDate?: any;
  description?: {} & {
    [key: string]: any;
  };
  id: string;
  image?: string;
  lastModified?: any;
  name?: {} & {
    [key: string]: any;
  };
  online?: boolean;
  pageDescription?: {} & {
    [key: string]: any;
  };
  pageKeywords?: {} & {
    [key: string]: any;
  };
  pageTitle?: {} & {
    [key: string]: any;
  };
  parentCategoryId?: string;
  paths?: Array<PathRecord>;
  position?: number;
  sortingRules?: Array<SortingRule>;
  thumbnail?: string;
} & {
  [key: string]: any;
};
export declare type VariationAttribute = {
  attributeDefinitionId: string;
  attributeDefinitionName?: {} & {
    [key: string]: any;
  };
  defaultValue?: string;
  id?: string;
  name?: {} & {
    [key: string]: any;
  };
  shared?: boolean;
  slicing?: boolean;
  values?: Array<VariationAttributeValue>;
  variationAttributeType?: string;
} & {
  [key: string]: any;
};
export declare type CatalogCategoryId = {
  catalogId: string;
  categoryId: string;
} & {
  [key: string]: any;
};
export declare type Categories = {
  limit: number;
  data: Array<Category>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SortingRule = {
  creationDate: any;
  description: string;
  id: string;
  productSortingRuleSteps: Array<SortingRuleStep>;
  ruleContext: string;
  site: string;
} & {
  [key: string]: any;
};
export declare type ProductType = {
  bundle?: boolean;
  bundled?: boolean;
  item?: boolean;
  master: boolean;
  option?: boolean;
  partOfProductSet?: boolean;
  partOfRetailSet?: boolean;
  retailSet?: boolean;
  set?: boolean;
  variant?: boolean;
  variationGroup?: boolean;
} & {
  [key: string]: any;
};
export declare type Variant = {
  ats?: number;
  defaultProductVariation?: boolean;
  image?: MediaFile;
  inStock?: boolean;
  online?: boolean;
  orderable?: boolean;
  price?: number;
  priceCurrency?: string;
  productId: string;
  searchable?: {} & {
    [key: string]: any;
  };
  variationAttributes?: Array<VariationAttribute>;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationGroup = {
  orderable: boolean;
  price: number;
  productId: string;
  variationValues: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type ProductOptionValue = {
  defaultProductOptionValue: boolean;
  id: string;
  optionPrices: Array<Money>;
  skuExtension: string;
  value: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationAttributes = {
  limit: number;
  data: Array<VariationAttribute>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CategoryLinks = {
  limit: number;
  data: Array<CategoryLink>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type MarkupText = {
  markup: string;
  source: string;
} & {
  [key: string]: any;
};
export declare type ImageGroup = {
  images: Array<MediaFile>;
  variationAttributes: Array<VariationAttribute>;
  viewType: string;
} & {
  [key: string]: any;
};
export declare type Catalogs = {
  limit: number;
  data: Array<Catalog>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CategoryLink = {
  lastModified: any;
  position: number;
  sourceCatalogId: string;
  sourceCatalogName: {} & {
    [key: string]: any;
  };
  sourceCategoryId: string;
  sourceCategoryName: {} & {
    [key: string]: any;
  };
  targetCatalogId: string;
  targetCatalogName: {} & {
    [key: string]: any;
  };
  targetCategoryId: string;
  targetCategoryName: {} & {
    [key: string]: any;
  };
  type: string;
} & {
  [key: string]: any;
};
export declare type MediaFile = {
  absUrl?: string;
  alt: {} & {
    [key: string]: any;
  };
  disBaseUrl?: string;
  path: string;
  title: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationAttributeValues = {
  limit: number;
  data: Array<VariationAttributeValue>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CatalogSearchResult = {
  hits: Array<Catalog>;
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type Site = {
  cartridges?: string;
  customerListLink?: CustomerListLink;
  description?: {} & {
    [key: string]: any;
  };
  displayName: {} & {
    [key: string]: any;
  };
  id: string;
  inDeletion?: boolean;
  storefrontStatus?: string;
} & {
  [key: string]: any;
};
export declare type ProductOptions = {
  limit: number;
  data: Array<ProductOption>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type Product = {
  assignedCategories?: Array<CatalogCategoryId>;
  ats?: number;
  brand?: string;
  bundledProducts?: Array<Product>;
  creationDate?: any;
  defaultVariantId?: string;
  ean?: string;
  id?: string;
  image?: MediaFile;
  imageGroups?: Array<ImageGroup>;
  inStock?: boolean;
  lastModified?: any;
  longDescription?: {} & {
    [key: string]: any;
  };
  manufacturerName?: string;
  manufacturerSku?: string;
  master?: Master;
  name?: {} & {
    [key: string]: any;
  };
  online?: boolean;
  onlineFlag?: {} & {
    [key: string]: any;
  };
  owningCatalogId?: string;
  owningCatalogName?: {} & {
    [key: string]: any;
  };
  pageDescription?: {} & {
    [key: string]: any;
  };
  pageKeywords?: {} & {
    [key: string]: any;
  };
  pageTitle?: {} & {
    [key: string]: any;
  };
  price?: number;
  priceCurrency?: string;
  primaryCategoryId?: string;
  productBundles?: Array<Product>;
  productOptions?: Array<ProductOption>;
  productSets?: Array<Product>;
  searchable?: {} & {
    [key: string]: any;
  };
  setProducts?: Array<Product>;
  shortDescription?: {} & {
    [key: string]: any;
  };
  type?: ProductType;
  unit?: string;
  upc?: string;
  variants?: Array<Variant>;
  variationAttributes?: Array<VariationAttribute>;
  variationGroups?: Array<VariationGroup>;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type CategoryProductAssignment = {
  catalogId: string;
  categoryId: string;
  owningCatalogName?: {} & {
    [key: string]: any;
  };
  position?: number;
  product?: Product;
  productId: string;
  productName?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationAttributeValue = {
  description?: {} & {
    [key: string]: any;
  };
  image?: MediaFile;
  imageSwatch?: MediaFile;
  name?: {} & {
    [key: string]: any;
  };
  orderable?: boolean;
  position?: number;
  value: string;
} & {
  [key: string]: any;
};
export declare type ProductOptionValues = {
  limit: number;
  data: Array<ProductOptionValue>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CustomerListLink = {
  customerListId: string;
  title?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type PathRecord = {
  id: string;
  name?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type Catalog = {
  assignedProductCount?: number;
  assignedSites?: Array<Site>;
  categoryCount?: number;
  creationDate?: any;
  description?: {} & {
    [key: string]: any;
  };
  id: string;
  lastModified?: any;
  name?: {} & {
    [key: string]: any;
  };
  online?: boolean;
  ownedProductCount?: number;
  recommendationCount?: number;
  rootCategory?: string;
} & {
  [key: string]: any;
};
export declare type SortingRuleStep = {
  attributeId: string;
  direction: string;
  isSystem: boolean;
  position: number;
  textRelevanceIncluded: boolean;
  typeId: string;
} & {
  [key: string]: any;
};
export declare type ErrorResponse = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type BoolFilter = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultBase = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type MatchAllQuery = {} & {
  [key: string]: any;
};
export declare type FilteredQuery = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilter = {
  query: any;
} & {
  [key: string]: any;
};
export declare type Query = {
  boolQuery?: BoolQuery;
  filteredQuery?: FilteredQuery;
  matchAllQuery?: MatchAllQuery;
  nestedQuery?: NestedQuery;
  termQuery?: TermQuery;
  textQuery?: TextQuery;
} & {
  [key: string]: any;
};
export declare type TermQuery = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilter = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQuery = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2Filter = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQuery = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultBase = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type NestedQuery = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type Filter = {
  boolFilter?: BoolFilter;
  queryFilter?: QueryFilter;
  range2Filter?: Range2Filter;
  rangeFilter?: RangeFilter;
  termFilter?: TermFilter;
} & {
  [key: string]: any;
};
export declare type Sort = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilter = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type SearchRequestBase = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResult = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequest = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResult = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ClosedObject = {} & {
  [key: string]: any;
};
export declare type OpenObject = {} & {
  [key: string]: any;
};
export declare type NoPropertiesAllowed = {};
export declare type SpecifiedPropertiesAllowed = {} & {
  [key: string]: any;
};
export declare type MoneyMnemonic = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
