/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type ErrorResponse = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type Money = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResult = {
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type SearchRequest = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: any;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResult = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type ClosedObject = {} & {
  [key: string]: any;
};
export declare type OpenObject = {} & {
  [key: string]: any;
};
export declare type NoPropertiesAllowed = {};
export declare type SpecifiedPropertiesAllowed = {} & {
  [key: string]: any;
};
export declare type MoneyMnemonic = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type BoolFilter = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultBase = {
  query: any;
  sorts?: Array<Sort>;
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type MatchAllQuery = {} & {
  [key: string]: any;
};
export declare type FilteredQuery = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilter = {
  query: any;
} & {
  [key: string]: any;
};
export declare type Query = {
  boolQuery?: BoolQuery;
  filteredQuery?: FilteredQuery;
  matchAllQuery?: MatchAllQuery;
  nestedQuery?: NestedQuery;
  termQuery?: TermQuery;
  textQuery?: TextQuery;
} & {
  [key: string]: any;
};
export declare type TermQuery = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilter = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQuery = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2Filter = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQuery = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultBase = {
  limit: number;
  hits?: Array<object>;
  offset: any;
  total: any;
} & {
  [key: string]: any;
};
export declare type NestedQuery = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type Filter = {
  boolFilter?: BoolFilter;
  queryFilter?: QueryFilter;
  range2Filter?: Range2Filter;
  rangeFilter?: RangeFilter;
  termFilter?: TermFilter;
} & {
  [key: string]: any;
};
export declare type Sort = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilter = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type SearchRequestBase = {
  limit?: number;
  query: any;
  sorts?: Array<Sort>;
  offset?: any;
} & {
  [key: string]: any;
};
export declare type ProductRef = {
  id: string;
} & {
  [key: string]: any;
};
export declare type SuggestedTerms = {
  originalTerm: string;
  terms?: Array<SuggestedTerm>;
} & {
  [key: string]: any;
};
export declare type CategorySuggestions = {
  categories?: Array<SuggestedCategory>;
  suggestedPhrases?: Array<SuggestedPhrase>;
  suggestedTerms: Array<SuggestedTerms>;
} & {
  [key: string]: any;
};
export declare type SuggestedProduct = {
  currency: string;
  image?: Image;
  price: number;
  productId: string;
  productName: string;
} & {
  [key: string]: any;
};
export declare type SuggestedPhrase = {
  exactMatch: boolean;
  phrase: string;
} & {
  [key: string]: any;
};
export declare type VariationAttribute = {
  id: string;
  name?: string;
  values?: Array<VariationAttributeValue>;
} & {
  [key: string]: any;
};
export declare type ProductSuggestions = {
  products?: Array<SuggestedProduct>;
  suggestedPhrases?: Array<SuggestedPhrase>;
  suggestedTerms: Array<SuggestedTerms>;
} & {
  [key: string]: any;
};
export declare type SuggestedCategory = {
  id: string;
  name: string;
  parentCategoryName: string;
} & {
  [key: string]: any;
};
export declare type ProductType = {
  bundle?: boolean;
  item?: boolean;
  master?: boolean;
  option?: boolean;
  set?: boolean;
  variant?: boolean;
  variationGroup?: boolean;
} & {
  [key: string]: any;
};
export declare type BrandSuggestions = {} & {
  [key: string]: any;
};
export declare type ProductSearchRefinementValue = {
  description?: string;
  hitCount: number;
  label: string;
  presentationId?: string;
  value: string;
  values?: Array<ProductSearchRefinementValue>;
} & {
  [key: string]: any;
};
export declare type ProductSearchSortingOption = {
  id: string;
  label: string;
} & {
  [key: string]: any;
};
export declare type SuggestedTerm = {
  completed: boolean;
  corrected: boolean;
  exactMatch: boolean;
  value: string;
} & {
  [key: string]: any;
};
export declare type ProductSearchRefinement = {
  attributeId: string;
  label?: string;
  values?: Array<ProductSearchRefinementValue>;
} & {
  [key: string]: any;
};
export declare type CustomSuggestions = {
  customSuggestion?: string;
  suggestedPhrases?: Array<SuggestedPhrase>;
  suggestedTerms: Array<SuggestedTerms>;
} & {
  [key: string]: any;
};
export declare type ProductSearchHit = {
  currency?: string;
  hitType?: string;
  image?: Image;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
  productId: string;
  productName?: string;
  productType?: ProductType;
  representedProduct?: ProductRef;
  representedProducts?: Array<ProductRef>;
  variationAttributes?: Array<VariationAttribute>;
} & {
  [key: string]: any;
};
export declare type ProductSearchResult = {
  limit: number;
  hits: Array<ProductSearchHit>;
  query: string;
  refinements: Array<ProductSearchRefinement>;
  searchPhraseSuggestions: Suggestion;
  selectedRefinements?: {} & {
    [key: string]: any;
  };
  selectedSortingOption?: string;
  sortingOptions: Array<ProductSearchSortingOption>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type Image = {
  alt?: string;
  disBaseLink?: string;
  link: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type VariationAttributeValue = {
  description?: string;
  image?: Image;
  imageSwatch?: Image;
  name?: string;
  orderable?: boolean;
  value: string;
} & {
  [key: string]: any;
};
export declare type Suggestion = {
  suggestedPhrases?: Array<SuggestedPhrase>;
  suggestedTerms: Array<SuggestedTerms>;
} & {
  [key: string]: any;
};
export declare type SuggestionResult = {
  brandSuggestions?: BrandSuggestions;
  categorySuggestions?: CategorySuggestions;
  productSuggestions?: ProductSuggestions;
  customSuggestion?: CustomSuggestions;
  searchPhrase: string;
} & {
  [key: string]: any;
};
